package com.zyc.system.service;

import java.util.List;
import com.zyc.system.domain.DamengDatabaseServices;

/**
 * 达梦数据库服务Service接口
 * 
 * @author zyc
 * @date 2024-12-26
 */
public interface IDamengDatabaseServicesService 
{
    /**
     * 查询达梦数据库服务
     * 
     * @param id 达梦数据库服务主键
     * @return 达梦数据库服务
     */
    public DamengDatabaseServices selectDamengDatabaseServicesById(Integer id);

    /**
     * 查询达梦数据库服务列表
     * 
     * @param damengDatabaseServices 达梦数据库服务
     * @return 达梦数据库服务集合
     */
    public List<DamengDatabaseServices> selectDamengDatabaseServicesList(DamengDatabaseServices damengDatabaseServices);

    /**
     * 新增达梦数据库服务
     * 
     * @param damengDatabaseServices 达梦数据库服务
     * @return 结果
     */
    public int insertDamengDatabaseServices(DamengDatabaseServices damengDatabaseServices);

    /**
     * 修改达梦数据库服务
     * 
     * @param damengDatabaseServices 达梦数据库服务
     * @return 结果
     */
    public int updateDamengDatabaseServices(DamengDatabaseServices damengDatabaseServices);

    /**
     * 批量删除达梦数据库服务
     * 
     * @param ids 需要删除的达梦数据库服务主键集合
     * @return 结果
     */
    public int deleteDamengDatabaseServicesByIds(Integer[] ids);

    /**
     * 删除达梦数据库服务信息
     * 
     * @param id 达梦数据库服务主键
     * @return 结果
     */
    public int deleteDamengDatabaseServicesById(Integer id);
}
